summaryrefslogtreecommitdiff
path: root/libusb/os/windows_usb.c
diff options
context:
space:
mode:
Diffstat (limited to 'libusb/os/windows_usb.c')
-rw-r--r--libusb/os/windows_usb.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/libusb/os/windows_usb.c b/libusb/os/windows_usb.c
index 6552ed6..908206e 100644
--- a/libusb/os/windows_usb.c
+++ b/libusb/os/windows_usb.c
@@ -1,6 +1,6 @@
/*
* windows backend for libusb 1.0
* Copyright (c) 2009-2010 Pete Batard <pbatard@gmail.com>
* With contributions from Michael Plante, Orin Eman et al.
* Parts of this code adapted from libusb-win32-v1 by Stephan Meyer
* Hash table functions adapted from glibc, by Ulrich Drepper et al.
@@ -22,7 +22,7 @@
*/
// COMPILATION OPTIONS:
// - Should libusb automatically claim (and release) the interfaces it requires?
#define AUTO_CLAIM
// - Forces instant overlapped completion on timeouts: can prevents extensive
// wait in poll, after a timeout, but might affect subsequent API calls.
@@ -699,7 +699,7 @@ static void auto_release(struct usbi_transfer *itransfer)
/*
* init: libusb backend init function
*
* This function enumerates the HCDs (Host Controller Drivers) and populates our private HCD list
* In our implementation, we equate Windows' "HCD" to LibUSB's "bus". Note that bus is zero indexed.
@@ -975,7 +975,7 @@ static int cache_config_descriptors(struct libusb_device *dev, HANDLE hub_handle
}
/*
* Populate a libusb device structure
*/
static int init_device(struct libusb_device* dev, struct libusb_device* parent_dev,
uint8_t port_number, char* device_id, DWORD devinst)
@@ -1179,7 +1179,7 @@ static int set_composite_interface(struct libusb_context* ctx, struct libusb_dev
}
/*
* get_device_list: libusb backend device enumeration function
*/
static int windows_get_device_list(struct libusb_context *ctx, struct discovered_devs **_discdevs)
{
@@ -1336,7 +1336,7 @@ static int windows_get_device_list(struct libusb_context *ctx, struct discovered
if (!pSetupDiGetDeviceRegistryPropertyA(dev_info, &dev_info_data, SPDRP_DRIVER,
&reg_type, (BYTE*)strbuf, size, &size)) {
usbi_info(ctx, "The following device has no driver: '%s'", dev_id_path);
- usbi_info(ctx, "libusb will not be able to access it.");
+ usbi_info(ctx, "libusbx will not be able to access it.");
}
// ...and to add the additional device interface GUIDs
key = pSetupDiOpenDevRegKey(dev_info, &dev_info_data, DICS_FLAG_GLOBAL, 0, DIREG_DEV, KEY_READ);
@@ -1522,7 +1522,7 @@ static int windows_get_device_list(struct libusb_context *ctx, struct discovered
}
/*
* exit: libusb backend deinitialization function
*/
static void windows_exit(void)
{
@@ -2941,7 +2941,7 @@ static int composite_submit_control_transfer(struct usbi_transfer *itransfer)
}
}
- usbi_err(ctx, "no libusb supported interfaces to complete request");
+ usbi_err(ctx, "no libusbx supported interfaces to complete request");
return LIBUSB_ERROR_NOT_FOUND;
}
@@ -1,6 +1,6 @@
/*
- * windows backend for libusb 1.0
- * Copyright (c) 2009-2010 Pete Batard <pbatard@gmail.com>
+ * windows backend for libusbx 1.0
+ * Copyright © 2009-2012 Pete Batard <pete@akeo.ie>
* With contributions from Michael Plante, Orin Eman et al.
* Parts of this code adapted from libusb-win32-v1 by Stephan Meyer
@@ -22,7 +22,7 @@
*/
// COMPILATION OPTIONS:
-// - Should libusb automatically claim (and release) the interfaces it requires?
+// - Should libusbx automatically claim (and release) the interfaces it requires?
#define AUTO_CLAIM
// - Forces instant overlapped completion on timeouts: can prevents extensive
@@ -699,7 +699,7 @@ static void auto_release(struct usbi_transfer *itransfer)
/*
- * init: libusb backend init function
+ * init: libusbx backend init function
*
* This function enumerates the HCDs (Host Controller Drivers) and populates our private HCD list
@@ -975,7 +975,7 @@ static int cache_config_descriptors(struct libusb_device *dev, HANDLE hub_handle
}
/*
- * Populate a libusb device structure
+ * Populate a libusbx device structure
*/
static int init_device(struct libusb_device* dev, struct libusb_device* parent_dev,
@@ -1179,7 +1179,7 @@ static int set_composite_interface(struct libusb_context* ctx, struct libusb_dev
}
/*
- * get_device_list: libusb backend device enumeration function
+ * get_device_list: libusbx backend device enumeration function
*/
static int windows_get_device_list(struct libusb_context *ctx, struct discovered_devs **_discdevs)
@@ -1522,7 +1522,7 @@ static int windows_get_device_list(struct libusb_context *ctx, struct discovered
}
/*
- * exit: libusb backend deinitialization function
+ * exit: libusbx backend deinitialization function
*/
static void windows_exit(void)